@@ -189,6 +189,13 @@ class pluginclass(object):
         self.menuFiles = []
         self.de = de
 
+        self.canOffload = False
+
+        try:
+            self.canOffload = XApp.util_gpu_offload_supported()
+        except AttributeError:
+            print("Could not check for gpu offload support - maybe xapps isn't up to date.");
+
         # Detect the locale (this is used for the Wikipedia search)
         self.lang = "en"
         lang = os.getenv('LANG')
@@ -836,6 +843,7 @@ class pluginclass(object):
             startupMenuItem = Gtk.CheckMenuItem(_("Launch when I log in"))
             separator3 = Gtk.SeparatorMenuItem()
             launchMenuItem = Gtk.MenuItem(_("Launch"))
+            launchOffloadedMenuItem = Gtk.MenuItem(_("Run with NVIDIA GPU"))
             removeFromFavMenuItem = Gtk.MenuItem(_("Remove from favorites"))
             separator4 = Gtk.SeparatorMenuItem()
             propsMenuItem = Gtk.MenuItem(_("Edit properties"))
@@ -851,6 +859,7 @@ class pluginclass(object):
                 startupMenuItem.set_active(False)
                 startupMenuItem.connect("toggled", self.onAddToStartup, widget)
             launchMenuItem.connect("activate", self.onLaunchApp, widget)
+            launchOffloadedMenuItem.connect("activate", self.onLaunchOffloadedApp, widget)
             removeFromFavMenuItem.connect("activate", self.onFavoritesRemove, widget)
             propsMenuItem.connect("activate", self.onPropsApp, widget)
 
@@ -864,6 +873,8 @@ class pluginclass(object):
             mTree.append(startupMenuItem)
             mTree.append(separator3)
             mTree.append(launchMenuItem)
+            if self.canOffload:
+                mTree.append(launchOffloadedMenuItem)
             mTree.append(removeFromFavMenuItem)
             mTree.append(separator4)
             mTree.append(propsMenuItem)
@@ -905,6 +916,7 @@ class pluginclass(object):
         startupMenuItem = Gtk.CheckMenuItem(_("Launch when I log in"))
         separator2 = Gtk.SeparatorMenuItem()
         launchMenuItem = Gtk.MenuItem(_("Launch"))
+        launchOffloadedMenuItem = Gtk.MenuItem(_("Run with NVIDIA GPU"))
         uninstallMenuItem = Gtk.MenuItem(_("Uninstall"))
         deleteMenuItem = Gtk.MenuItem(_("Delete from menu"))
         separator3 = Gtk.SeparatorMenuItem()
@@ -919,6 +931,8 @@ class pluginclass(object):
         mTree.append(startupMenuItem)
         mTree.append(separator2)
         mTree.append(launchMenuItem)
+        if self.canOffload:
+            mTree.append(launchOffloadedMenuItem)
         mTree.append(uninstallMenuItem)
         if home in widget.desktopFile:
             mTree.append(deleteMenuItem)
@@ -930,6 +944,7 @@ class pluginclass(object):
         desktopMenuItem.connect("activate", self.add_to_desktop, widget)
         panelMenuItem.connect("activate", self.add_to_panel, widget)
         launchMenuItem.connect("activate", self.onLaunchApp, widget)
+        launchOffloadedMenuItem.connect("activate", self.onLaunchOffloadedApp, widget)
         propsMenuItem.connect("activate", self.onPropsApp, widget)
         uninstallMenuItem.connect("activate", self.onUninstallApp, widget)
 
@@ -1071,6 +1086,10 @@ class pluginclass(object):
         widget.execute()
         self.mintMenuWin.hide()
 
+    def onLaunchOffloadedApp(self, menu, widget):
+        widget.execute(offload=True)
+        self.mintMenuWin.hide()
+
     def onPropsApp(self, menu, widget):
         newFileFlag = False
         sysPaths = get_system_item_paths()
